@@ -242,9 +242,9 @@ static MagickBooleanType ReadHEICExifProfile(Image *image,
       length=GetStringInfoLength(exif_profile);
       datum=GetStringInfoDatum(exif_profile);
       if ((length > 2) && 
-          ((memcmp(datum,"\0xFF\0xD8",2) == 0) ||
-           (memcmp(datum,"\0xFF\0xE1",2) == 0)) &&
-           memcmp(datum+length-2,"\0xFF\0xD9",2) == 0)
+          ((memcmp(datum,"\xff\xd8",2) == 0) ||
+           (memcmp(datum,"\xff\xe1",2) == 0)) &&
+           memcmp(datum+length-2,"\xff\xd9",2) == 0)
         SetStringInfoLength(exif_profile,length-2);
       /*
         Skip to actual Exif payload.
@@ -451,15 +451,16 @@ static MagickBooleanType ReadHEICImageHandle(const ImageInfo *image_info,
       p=pixels+(y*stride);
       for (x=0; x < (ssize_t) image->columns; x++)
       {
-        unsigned short pixel = ((*(p+1) << 8) | (*(p+0))) << shift; p+=2;
+        unsigned short pixel = (((unsigned short) *(p+1) << 8) |
+          (*(p+0))) << shift; p+=2;
         SetPixelRed(image,ScaleShortToQuantum(pixel),q);
-        pixel=((*(p+1) << 8) | (*(p+0))) << shift; p+=2;
+        pixel=(((unsigned short) *(p+1) << 8) | (*(p+0))) << shift; p+=2;
         SetPixelGreen(image,ScaleShortToQuantum(pixel),q);
-        pixel=((*(p+1) << 8) | (*(p+0))) << shift; p+=2;
+        pixel=(((unsigned short) *(p+1) << 8) | (*(p+0))) << shift; p+=2;
         SetPixelBlue(image,ScaleShortToQuantum(pixel),q);
         if (image->alpha_trait != UndefinedPixelTrait)
           {
-            pixel=((*(p+1) << 8) | (*(p+0))) << shift; p+=2;
+            pixel=(((unsigned short) *(p+1) << 8) | (*(p+0))) << shift; p+=2;
             SetPixelAlpha(image,ScaleShortToQuantum(pixel),q);
           }
         q+=GetPixelChannels(image);
