@@ -851,6 +851,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     if (*id != '\0')
                       {
                         options=DestroyString(options);
+                        if (profiles != (LinkedListInfo *) NULL)
+                          profiles=DestroyLinkedList(profiles,
+                            RelinquishMagickMemory);
                         ThrowMIFFException(CorruptImageError,
                           "ImproperImageHeader");
                       }
@@ -1351,6 +1354,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
       packet_size+=image->depth/8;
     if (image->compression == RLECompression)
       packet_size++;
+    if (image->number_meta_channels != 0)
+      packet_size+=image->number_meta_channels*image->depth/8;
     compress_extent=MagickMax(MagickMax(BZipMaxExtent(packet_size*
       image->columns),LZMAMaxExtent(packet_size*image->columns)),
       ZipMaxExtent(packet_size*image->columns));
@@ -2064,15 +2069,13 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   QuantumType
     quantum_type;
 
-  ssize_t
-    i;
-
   size_t
-    imageListLength,
     length,
+    number_scenes,
     packet_size;
 
   ssize_t
+    i,
     y;
 
   unsigned char
@@ -2100,7 +2103,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return(status);
   scene=0;
-  imageListLength=GetImageListLength(image);
+  number_scenes=GetImageListLength(image);
   do
   {
     /*
@@ -2163,6 +2166,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       packet_size+=image->depth/8;
     if (compression == RLECompression)
       packet_size++;
+    if (image->number_meta_channels != 0)
+      packet_size+=image->number_meta_channels*image->depth/8;
     length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
       packet_size*image->columns));
     if ((compression == BZipCompression) || (compression == ZipCompression))
@@ -2327,7 +2332,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (image->chromaticity.white_point.x != 0.0)
       {
         /*
-          Note chomaticity points.
+          Note chromaticity points.
         */
         (void) FormatLocaleString(buffer,MagickPathExtent,"red-primary=%g,%g "
           "green-primary=%g,%g blue-primary=%g,%g\n",
@@ -2835,7 +2840,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
-    status=SetImageProgress(image,SaveImagesTag,scene++,imageListLength);
+    status=SetImageProgress(image,SaveImagesTag,scene++,number_scenes);
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
