@@ -517,22 +517,20 @@ static int UnpackWPGRaster(Image *image,int bpp,ExceptionInfo *exception)
             BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
             return(-3);
           }
-          for(i=0;i < (int) RunCount;i++)
-            {
-              x=0;
-              y++;    /* Here I need to duplicate previous row RUNCOUNT* */
-              if(y<2) continue;
-              if(y>(ssize_t) image->rows)
-                {
-                  BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-                  return(-4);
-                }
-              if (InsertRow(image,BImgBuff,y-1,bpp,exception) == MagickFalse)
-                {
-                  BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-                  return(-5);
-                }
-            }
+          for (i=0; i < (int) RunCount; i++)
+          {
+            if (y >= (ssize_t) image->rows)
+              {
+                BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
+                return(-4);
+              }
+            if (InsertRow(image,BImgBuff,y,bpp,exception) == MagickFalse)
+              {
+                BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
+                return(-6);
+              }
+            y++;
+          }
         }
       }
       if (EOFBlob(image) != MagickFalse)
@@ -568,15 +566,11 @@ static int UnpackWPG2Raster(Image *image,int bpp,ExceptionInfo *exception)
     XorMe = 0;
 
   ssize_t
-    i;
-
-  size_t
+    i,
+    ldblk,
     x,
     y;
 
-  ssize_t
-    ldblk;
-
   unsigned int
     SampleSize=1;
 
@@ -594,7 +588,7 @@ static int UnpackWPG2Raster(Image *image,int bpp,ExceptionInfo *exception)
     return(-2);
   (void) memset(BImgBuff,0,ldblk*sizeof(*BImgBuff));
 
-  while( y< image->rows)
+  while( y< (ssize_t) image->rows)
   {
       bbuf=ReadBlobByte(image);
 
@@ -652,7 +646,7 @@ static int UnpackWPG2Raster(Image *image,int bpp,ExceptionInfo *exception)
             /* duplicate the previous row RunCount x */
             for(i=0;i<=RunCount;i++)
               {
-                if (InsertRow(image,BImgBuff,(ssize_t) (image->rows > y ? y : image->rows-1),bpp,exception) == MagickFalse)
+                if (InsertRow(image,BImgBuff,(ssize_t) ((ssize_t) image->rows > y ? y : image->rows-1),bpp,exception) == MagickFalse)
                   {
                     BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
                     return(-3);
@@ -1906,7 +1900,7 @@ static MagickBooleanType WriteWPGImage(const ImageInfo *image_info,Image *image,
       (void) WriteBlobLSBShort(image,0); /* start index */
       (void) WriteBlobLSBShort(image,1U << image->depth);
       for ( ; i < (ssize_t) ((size_t) 1U << image->depth); i++)
-        if (i >= image->colors)
+        if (i >= (ssize_t) image->colors)
           {
             (void) WriteBlobByte(image,i);
             (void) WriteBlobByte(image,i);
